pub struct FlashExtractor(pub Vec<FlashMessage>);Expand description
Extractor for flash messages
Extracts flash messages from the session and clears them from the session data. Messages are typically shown once and then cleared (flash = one-time display).
Note
This extractor takes the flash messages from the session data in extensions, clearing them so they won’t be persisted back. The middleware will save the modified session data (without the flashes) on response.
Example
use acton_htmx::extractors::FlashExtractor;
async fn handler(FlashExtractor(messages): FlashExtractor) {
for msg in messages {
println!("Flash: {:?} - {}", msg.level, msg.message);
}
}Tuple Fields
0: Vec<FlashMessage>Trait Implementations
Sourceimpl Clone for FlashExtractor
impl Clone for FlashExtractor
Sourcefn clone(&self) -> FlashExtractor
fn clone(&self) -> FlashExtractor
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FlashExtractor
impl Debug for FlashExtractor
Sourceimpl Default for FlashExtractor
impl Default for FlashExtractor
Sourcefn default() -> FlashExtractor
fn default() -> FlashExtractor
Sourceimpl<S> FromRequestParts<S> for FlashExtractor
impl<S> FromRequestParts<S> for FlashExtractor