pub struct FormBuilder<'a> { /* private fields */ }Expand description
Builder for constructing HTML forms
Examples
use acton_htmx::forms::{FormBuilder, InputType};
let html = FormBuilder::new("/login", "POST")
.id("login-form")
.csrf_token("abc123")
.field("email", InputType::Email)
.label("Email Address")
.required()
.placeholder("you@example.com")
.done()
.field("password", InputType::Password)
.label("Password")
.required()
.done()
.submit("Sign In")
.build();Implementations
Sourceimpl<'a> FormBuilder<'a>
impl<'a> FormBuilder<'a>
Sourcepub fn new(action: impl Into<String>, method: impl Into<String>) -> Self
pub fn new(action: impl Into<String>, method: impl Into<String>) -> Self
Create a new form builder with action and method
Sourcepub fn csrf_token(self, token: impl Into<String>) -> Self
pub fn csrf_token(self, token: impl Into<String>) -> Self
Set the CSRF token
Sourcepub fn enctype(self, enctype: impl Into<String>) -> Self
pub fn enctype(self, enctype: impl Into<String>) -> Self
Set the form enctype (for file uploads use “multipart/form-data”)
Sourcepub const fn errors(self, errors: &'a ValidationErrors) -> Self
pub const fn errors(self, errors: &'a ValidationErrors) -> Self
Set validation errors to display
Sourcepub fn submit_class(self, class: impl Into<String>) -> Self
pub fn submit_class(self, class: impl Into<String>) -> Self
Set the submit button CSS class
Sourcepub const fn novalidate(self) -> Self
pub const fn novalidate(self) -> Self
Disable browser validation (add novalidate attribute)
Sourcepub fn attr(self, name: impl Into<String>, value: impl Into<String>) -> Self
pub fn attr(self, name: impl Into<String>, value: impl Into<String>) -> Self
Add a custom attribute
Sourcepub fn htmx_delete(self, url: impl Into<String>) -> Self
pub fn htmx_delete(self, url: impl Into<String>) -> Self
Set hx-delete attribute
Sourcepub fn htmx_patch(self, url: impl Into<String>) -> Self
pub fn htmx_patch(self, url: impl Into<String>) -> Self
Set hx-patch attribute
Sourcepub fn htmx_target(self, selector: impl Into<String>) -> Self
pub fn htmx_target(self, selector: impl Into<String>) -> Self
Set hx-target attribute
Sourcepub fn htmx_trigger(self, trigger: impl Into<String>) -> Self
pub fn htmx_trigger(self, trigger: impl Into<String>) -> Self
Set hx-trigger attribute
Sourcepub fn htmx_indicator(self, selector: impl Into<String>) -> Self
pub fn htmx_indicator(self, selector: impl Into<String>) -> Self
Set hx-indicator attribute
Sourcepub fn htmx_push_url(self, url: impl Into<String>) -> Self
pub fn htmx_push_url(self, url: impl Into<String>) -> Self
Set hx-push-url attribute
Sourcepub fn htmx_confirm(self, message: impl Into<String>) -> Self
pub fn htmx_confirm(self, message: impl Into<String>) -> Self
Set hx-confirm attribute
Sourcepub fn htmx_disabled_elt(self, selector: impl Into<String>) -> Self
pub fn htmx_disabled_elt(self, selector: impl Into<String>) -> Self
Set hx-disabled-elt attribute
Sourcepub const fn htmx_validate(self) -> Self
pub const fn htmx_validate(self) -> Self
Enable hx-validate
Sourcepub fn field(
self,
name: impl Into<String>,
input_type: InputType,
) -> FieldBuilder<'a>
pub fn field( self, name: impl Into<String>, input_type: InputType, ) -> FieldBuilder<'a>
Add an input field and return a field builder
Sourcepub fn file(self, name: impl Into<String>) -> FileFieldBuilder<'a>
pub fn file(self, name: impl Into<String>) -> FileFieldBuilder<'a>
Add a file upload field and return a file field builder
This automatically sets the form enctype to multipart/form-data.
Examples
use acton_htmx::forms::FormBuilder;
let form = FormBuilder::new("/upload", "POST")
.file("avatar")
.label("Profile Picture")
.accept("image/png,image/jpeg")
.max_size_mb(5)
.required()
.done()
.build();Sourcepub fn textarea(self, name: impl Into<String>) -> TextareaBuilder<'a>
pub fn textarea(self, name: impl Into<String>) -> TextareaBuilder<'a>
Add a textarea field and return a field builder
Sourcepub fn select(self, name: impl Into<String>) -> SelectBuilder<'a>
pub fn select(self, name: impl Into<String>) -> SelectBuilder<'a>
Add a select field and return a select builder
Sourcepub fn checkbox(self, name: impl Into<String>) -> CheckboxBuilder<'a>
pub fn checkbox(self, name: impl Into<String>) -> CheckboxBuilder<'a>
Add a checkbox field and return a checkbox builder
Add a hidden field
Sourcepub fn build(self) -> String
pub fn build(self) -> String
Build the form HTML using programmatic rendering
This uses the built-in programmatic renderer. For template-based
rendering that allows customization, use [build_with_templates].
Sourcepub fn build_with_templates(
self,
templates: &FrameworkTemplates,
) -> Result<String, FormRenderError>
pub fn build_with_templates( self, templates: &FrameworkTemplates, ) -> Result<String, FormRenderError>
Build the form HTML using template-based rendering
This uses minijinja templates from the XDG template directory, allowing users to customize the HTML structure.
Errors
Returns error if template rendering fails.
Example
use acton_htmx::forms::{FormBuilder, InputType};
use acton_htmx::template::framework::FrameworkTemplates;
let templates = FrameworkTemplates::new()?;
let html = FormBuilder::new("/login", "POST")
.field("email", InputType::Email)
.label("Email")
.done()
.build_with_templates(&templates)?;Sourcepub fn build_with_templates_and_options(
self,
templates: &FrameworkTemplates,
options: FormRenderOptions,
) -> Result<String, FormRenderError>
pub fn build_with_templates_and_options( self, templates: &FrameworkTemplates, options: FormRenderOptions, ) -> Result<String, FormRenderError>
Build the form HTML using template-based rendering with custom options
Errors
Returns error if template rendering fails.