pub struct HxCurrentUrl(pub Option<Uri>);Expand description
The HX-Current-Url header.
This is set on every request made by htmx itself. As its name implies, it just contains the current url.
This extractor will always return a value. If the header is not present, or
extractor fails to parse the url it will return None.
Tuple Fields
0: Option<Uri>Trait Implementations
Sourceimpl Clone for HxCurrentUrl
impl Clone for HxCurrentUrl
Sourcefn clone(&self) -> HxCurrentUrl
fn clone(&self) -> HxCurrentUrl
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HxCurrentUrl
impl Debug for HxCurrentUrl
Sourceimpl<S> FromRequestParts<S> for HxCurrentUrl
impl<S> FromRequestParts<S> for HxCurrentUrl
Sourcetype Rejection = Infallible
type Rejection = Infallible
Sourceasync fn from_request_parts(
parts: &mut Parts,
_: &S,
) -> Result<HxCurrentUrl, <HxCurrentUrl as FromRequestParts<S>>::Rejection>
async fn from_request_parts( parts: &mut Parts, _: &S, ) -> Result<HxCurrentUrl, <HxCurrentUrl as FromRequestParts<S>>::Rejection>