pub struct HxLocation {
pub uri: String,
pub options: LocationOptions,
}Expand description
The HX-Location header.
This response header can be used to trigger a client side redirection
without reloading the whole page. If you intend to redirect to a specific
target on the page, you must enable the serde feature flag and specify
LocationOptions.
Will fail if the supplied uri contains characters that are not visible ASCII (32-127).
See https://htmx.org/headers/hx-location/ for more information.
Fields
uri: StringUri of the new location.
options: LocationOptionsExtra options.
Implementations
Sourceimpl HxLocation
impl HxLocation
Sourcepub fn from_str(uri: impl AsRef<str>) -> HxLocation
pub fn from_str(uri: impl AsRef<str>) -> HxLocation
Parses uri and sets it as location.
Sourcepub fn from_str_with_options(
uri: impl AsRef<str>,
options: LocationOptions,
) -> HxLocation
pub fn from_str_with_options( uri: impl AsRef<str>, options: LocationOptions, ) -> HxLocation
Parses uri and sets it as location with additional options.