pub struct HxPrompt(pub Option<String>);Expand description
The HX-Prompt header.
This is set when a request is made from an element that has the hx-prompt
attribute set. The value will contain the string input by the user.
This extractor will always return a value. If the header is not present, it
will return None.
Tuple Fields
0: Option<String>Trait Implementations
Sourceimpl<S> FromRequestParts<S> for HxPrompt
impl<S> FromRequestParts<S> for HxPrompt
Sourcetype Rejection = Infallible
type Rejection = Infallible
Sourceasync fn from_request_parts(
parts: &mut Parts,
_: &S,
) -> Result<HxPrompt, <HxPrompt as FromRequestParts<S>>::Rejection>
async fn from_request_parts( parts: &mut Parts, _: &S, ) -> Result<HxPrompt, <HxPrompt as FromRequestParts<S>>::Rejection>