pub struct HxRequest(pub bool);Expand description
The HX-Request header.
This is set on every request made by htmx itself. It won’t be present on requests made manually, or by other libraries.
This extractor will always return a value. If the header is not present, it
will return false.
Tuple Fields
0: boolImplementations
Sourceimpl HxRequest
impl HxRequest
Sourcepub fn vary_response() -> VaryHxRequest
pub fn vary_response() -> VaryHxRequest
Convenience method to create the corresponding Vary response header