pub struct HxRequestGuardLayer<'a> { /* private fields */ }Expand description
Checks if the request contains the HX-Request header, redirecting to the
given location if not.
This can be useful for preventing users from accidently ending up on a route which would otherwise return only partial HTML data.
Implementations
Sourceimpl<'a> HxRequestGuardLayer<'a>
impl<'a> HxRequestGuardLayer<'a>
pub fn new(redirect_to: &'a str) -> HxRequestGuardLayer<'a>