pub struct HxReselect(pub String);Expand description
The HX-Reselect header.
A CSS selector that allows you to choose which part of the response is used to be swapped in. Overrides an existing hx-select on the triggering element.
Will fail if the supplied String contains characters that are not visible ASCII (32-127).
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for HxReselect
impl Clone for HxReselect
Sourcefn clone(&self) -> HxReselect
fn clone(&self) -> HxReselect
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HxReselect
impl Debug for HxReselect
Sourceimpl<T> From<T> for HxReselect
impl<T> From<T> for HxReselect
Sourcefn from(value: T) -> HxReselect
fn from(value: T) -> HxReselect
Sourceimpl IntoResponseParts for HxReselect
impl IntoResponseParts for HxReselect
Sourcefn into_response_parts(
self,
res: ResponseParts,
) -> Result<ResponseParts, <HxReselect as IntoResponseParts>::Error>
fn into_response_parts( self, res: ResponseParts, ) -> Result<ResponseParts, <HxReselect as IntoResponseParts>::Error>