pub struct HxResponseTrigger {
pub mode: TriggerMode,
pub events: Vec<HxEvent>,
}Expand description
The HX-Trigger* header.
Allows you to trigger client-side events. Corresponds to HX-Trigger,
HX-Trigger-After-Settle and HX-Trigger-After-Swap headers. To change
when events trigger use appropriate mode.
Will fail if the supplied events contain or produce characters that are not visible ASCII (32-127) when serializing to JSON.
See https://htmx.org/headers/hx-trigger/ for more information.
Note: An HxResponseTrigger implements IntoResponseParts and should be
used before any other response object would consume the response parts.
Fields
mode: TriggerModeevents: Vec<HxEvent>Implementations
Sourceimpl HxResponseTrigger
impl HxResponseTrigger
Sourcepub fn new<T>(
mode: TriggerMode,
events: impl IntoIterator<Item = T>,
) -> HxResponseTrigger
pub fn new<T>( mode: TriggerMode, events: impl IntoIterator<Item = T>, ) -> HxResponseTrigger
Creates new trigger with specified mode and events.
Sourcepub fn normal<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
pub fn normal<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
Creates new normal trigger from events.
See HxResponseTrigger for more information.
Sourcepub fn after_settle<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
pub fn after_settle<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
Creates new after settle trigger from events.
See HxResponseTrigger for more information.
Sourcepub fn after_swap<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
pub fn after_swap<T>(events: impl IntoIterator<Item = T>) -> HxResponseTrigger
Creates new after swap trigger from events.
See HxResponseTrigger for more information.